var hierarchy =
[
    [ "BrownNoise< SamplePrecision >", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1BrownNoise.html", null ],
    [ "CBaseObject", null, [
      [ "EventLogDataBrowserSource", "classVSTGUI_1_1EventLogDataBrowserSource.html", null ],
      [ "PitchNamesDataBrowserSource", "classVSTGUI_1_1PitchNamesDataBrowserSource.html", null ]
    ] ],
    [ "DataBrowserDelegateAdapter", null, [
      [ "EventLogDataBrowserSource", "classVSTGUI_1_1EventLogDataBrowserSource.html", null ],
      [ "PitchNamesDataBrowserSource", "classVSTGUI_1_1PitchNamesDataBrowserSource.html", null ]
    ] ],
    [ "EventListCheck", "classEventListCheck.html", null ],
    [ "EventLogger", "classEventLogger.html", null ],
    [ "Filter", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1Filter.html", null ],
    [ "FObject", null, [
      [ "EditorSizeController", "classSteinberg_1_1Vst_1_1EditorSizeController.html", null ],
      [ "TestSuite", "classSteinberg_1_1Vst_1_1TestSuite.html", null ],
      [ "Test", "classSteinberg_1_1Vst_1_1TestSuite_1_1Test.html", null ],
      [ "Validator", "classSteinberg_1_1Vst_1_1Validator.html", null ]
    ] ],
    [ "FUnknown", "../base/classSteinberg_1_1FUnknown.html", [
      [ "IPluginBase", "../base/classSteinberg_1_1IPluginBase.html", [
        [ "ComponentBase", "../vstsdk/classSteinberg_1_1Vst_1_1ComponentBase.html", [
          [ "Component", "../vstsdk/classSteinberg_1_1Vst_1_1Component.html", [
            [ "AudioEffect", "../vstsdk/classSteinberg_1_1Vst_1_1AudioEffect.html", [
              [ "ADelayProcessor", "classSteinberg_1_1Vst_1_1ADelayProcessor.html", null ],
              [ "AGain", "classSteinberg_1_1Vst_1_1AGain.html", [
                [ "AGainWithSideChain", "classSteinberg_1_1Vst_1_1AGainWithSideChain.html", null ]
              ] ],
              [ "HostCheckerProcessor", "classSteinberg_1_1Vst_1_1HostCheckerProcessor.html", null ],
              [ "Plug", "classSteinberg_1_1Vst_1_1LegacyMIDICCOut_1_1Plug.html", null ],
              [ "Processor", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1Processor.html", [
                [ "ProcessorWithUIController", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ProcessorWithUIController.html", null ]
              ] ],
              [ "PitchNamesProcessor", "classSteinberg_1_1Vst_1_1PitchNamesProcessor.html", null ],
              [ "Plug", "classSteinberg_1_1Vst_1_1Plug.html", null ],
              [ "Plug", "classSteinberg_1_1Vst_1_1Plug.html", null ],
              [ "Plug", "classSteinberg_1_1Vst_1_1Plug.html", null ],
              [ "Plug", "classSteinberg_1_1Vst_1_1Plug.html", null ],
              [ "SyncDelayProcessor", "classSteinberg_1_1Vst_1_1SyncDelayProcessor.html", null ],
              [ "Processor", "classSteinberg_1_1Vst_1_1mda_1_1Processor.html", [
                [ "SampleAccurateBaseProcessor", "classSteinberg_1_1Vst_1_1mda_1_1SampleAccurateBaseProcessor.html", [
                  [ "AmbienceProcessor", "classSteinberg_1_1Vst_1_1mda_1_1AmbienceProcessor.html", null ],
                  [ "BandistoProcessor", "classSteinberg_1_1Vst_1_1mda_1_1BandistoProcessor.html", null ],
                  [ "BeatBoxProcessor", "classSteinberg_1_1Vst_1_1mda_1_1BeatBoxProcessor.html", null ],
                  [ "ComboProcessor", "classSteinberg_1_1Vst_1_1mda_1_1ComboProcessor.html", null ],
                  [ "DX10Processor", "classSteinberg_1_1Vst_1_1mda_1_1DX10Processor.html", null ],
                  [ "DeEsserProcessor", "classSteinberg_1_1Vst_1_1mda_1_1DeEsserProcessor.html", null ],
                  [ "DegradeProcessor", "classSteinberg_1_1Vst_1_1mda_1_1DegradeProcessor.html", null ],
                  [ "DelayProcessor", "classSteinberg_1_1Vst_1_1mda_1_1DelayProcessor.html", null ],
                  [ "DetuneProcessor", "classSteinberg_1_1Vst_1_1mda_1_1DetuneProcessor.html", null ],
                  [ "DitherProcessor", "classSteinberg_1_1Vst_1_1mda_1_1DitherProcessor.html", null ],
                  [ "DubDelayProcessor", "classSteinberg_1_1Vst_1_1mda_1_1DubDelayProcessor.html", null ],
                  [ "DynamicsProcessor", "classSteinberg_1_1Vst_1_1mda_1_1DynamicsProcessor.html", null ],
                  [ "EPianoProcessor", "classSteinberg_1_1Vst_1_1mda_1_1EPianoProcessor.html", null ],
                  [ "ImageProcessor", "classSteinberg_1_1Vst_1_1mda_1_1ImageProcessor.html", null ],
                  [ "JX10Processor", "classSteinberg_1_1Vst_1_1mda_1_1JX10Processor.html", null ],
                  [ "LeslieProcessor", "classSteinberg_1_1Vst_1_1mda_1_1LeslieProcessor.html", null ],
                  [ "LimiterProcessor", "classSteinberg_1_1Vst_1_1mda_1_1LimiterProcessor.html", null ],
                  [ "LoudnessProcessor", "classSteinberg_1_1Vst_1_1mda_1_1LoudnessProcessor.html", null ],
                  [ "MultiBandProcessor", "classSteinberg_1_1Vst_1_1mda_1_1MultiBandProcessor.html", null ],
                  [ "OverdriveProcessor", "classSteinberg_1_1Vst_1_1mda_1_1OverdriveProcessor.html", null ],
                  [ "PianoProcessor", "classSteinberg_1_1Vst_1_1mda_1_1PianoProcessor.html", null ],
                  [ "RePsychoProcessor", "classSteinberg_1_1Vst_1_1mda_1_1RePsychoProcessor.html", null ],
                  [ "RezFilterProcessor", "classSteinberg_1_1Vst_1_1mda_1_1RezFilterProcessor.html", null ],
                  [ "RingModProcessor", "classSteinberg_1_1Vst_1_1mda_1_1RingModProcessor.html", null ],
                  [ "RoundPanProcessor", "classSteinberg_1_1Vst_1_1mda_1_1RoundPanProcessor.html", null ],
                  [ "ShepardProcessor", "classSteinberg_1_1Vst_1_1mda_1_1ShepardProcessor.html", null ],
                  [ "SpecMeterProcessor", "classSteinberg_1_1Vst_1_1mda_1_1SpecMeterProcessor.html", null ],
                  [ "SplitterProcessor", "classSteinberg_1_1Vst_1_1mda_1_1SplitterProcessor.html", null ],
                  [ "StereoProcessor", "classSteinberg_1_1Vst_1_1mda_1_1StereoProcessor.html", null ],
                  [ "SubSynthProcessor", "classSteinberg_1_1Vst_1_1mda_1_1SubSynthProcessor.html", null ],
                  [ "TalkBoxProcessor", "classSteinberg_1_1Vst_1_1mda_1_1TalkBoxProcessor.html", null ],
                  [ "TestToneProcessor", "classSteinberg_1_1Vst_1_1mda_1_1TestToneProcessor.html", null ],
                  [ "ThruZeroProcessor", "classSteinberg_1_1Vst_1_1mda_1_1ThruZeroProcessor.html", null ],
                  [ "TrackerProcessor", "classSteinberg_1_1Vst_1_1mda_1_1TrackerProcessor.html", null ]
                ] ]
              ] ]
            ] ]
          ] ],
          [ "EditController", "../vstsdk/classSteinberg_1_1Vst_1_1EditController.html", [
            [ "ADelayController", "classSteinberg_1_1Vst_1_1ADelayController.html", null ],
            [ "EditControllerEx1", "../vstsdk/classSteinberg_1_1Vst_1_1EditControllerEx1.html", [
              [ "AGainController", "classSteinberg_1_1Vst_1_1AGainController.html", null ],
              [ "HostCheckerController", "classSteinberg_1_1Vst_1_1HostCheckerController.html", null ],
              [ "PlugController", "classSteinberg_1_1Vst_1_1LegacyMIDICCOut_1_1PlugController.html", null ],
              [ "PitchNamesController", "classSteinberg_1_1Vst_1_1PitchNamesController.html", null ],
              [ "PlugController", "classSteinberg_1_1Vst_1_1PlugController.html", null ],
              [ "PlugController", "classSteinberg_1_1Vst_1_1PlugController.html", null ],
              [ "PlugController", "classSteinberg_1_1Vst_1_1PlugController.html", null ],
              [ "PlugController", "classSteinberg_1_1Vst_1_1PlugController.html", null ],
              [ "BaseController", "classSteinberg_1_1Vst_1_1mda_1_1BaseController.html", [
                [ "AmbienceController", "classSteinberg_1_1Vst_1_1mda_1_1AmbienceController.html", null ],
                [ "BandistoController", "classSteinberg_1_1Vst_1_1mda_1_1BandistoController.html", null ],
                [ "BeatBoxController", "classSteinberg_1_1Vst_1_1mda_1_1BeatBoxController.html", null ],
                [ "ComboController", "classSteinberg_1_1Vst_1_1mda_1_1ComboController.html", null ],
                [ "DX10Controller", "classSteinberg_1_1Vst_1_1mda_1_1DX10Controller.html", null ],
                [ "DeEsserController", "classSteinberg_1_1Vst_1_1mda_1_1DeEsserController.html", null ],
                [ "DegradeController", "classSteinberg_1_1Vst_1_1mda_1_1DegradeController.html", null ],
                [ "DelayController", "classSteinberg_1_1Vst_1_1mda_1_1DelayController.html", null ],
                [ "DetuneController", "classSteinberg_1_1Vst_1_1mda_1_1DetuneController.html", null ],
                [ "DitherController", "classSteinberg_1_1Vst_1_1mda_1_1DitherController.html", null ],
                [ "DubDelayController", "classSteinberg_1_1Vst_1_1mda_1_1DubDelayController.html", null ],
                [ "DynamicsController", "classSteinberg_1_1Vst_1_1mda_1_1DynamicsController.html", null ],
                [ "EPianoController", "classSteinberg_1_1Vst_1_1mda_1_1EPianoController.html", null ],
                [ "ImageController", "classSteinberg_1_1Vst_1_1mda_1_1ImageController.html", null ],
                [ "JX10Controller", "classSteinberg_1_1Vst_1_1mda_1_1JX10Controller.html", null ],
                [ "LeslieController", "classSteinberg_1_1Vst_1_1mda_1_1LeslieController.html", null ],
                [ "LimiterController", "classSteinberg_1_1Vst_1_1mda_1_1LimiterController.html", null ],
                [ "LoudnessController", "classSteinberg_1_1Vst_1_1mda_1_1LoudnessController.html", null ],
                [ "MultiBandController", "classSteinberg_1_1Vst_1_1mda_1_1MultiBandController.html", null ],
                [ "OverdriveController", "classSteinberg_1_1Vst_1_1mda_1_1OverdriveController.html", null ],
                [ "PianoController", "classSteinberg_1_1Vst_1_1mda_1_1PianoController.html", null ],
                [ "RePsychoController", "classSteinberg_1_1Vst_1_1mda_1_1RePsychoController.html", null ],
                [ "RezFilterController", "classSteinberg_1_1Vst_1_1mda_1_1RezFilterController.html", null ],
                [ "RingModController", "classSteinberg_1_1Vst_1_1mda_1_1RingModController.html", null ],
                [ "RoundPanController", "classSteinberg_1_1Vst_1_1mda_1_1RoundPanController.html", null ],
                [ "ShepardController", "classSteinberg_1_1Vst_1_1mda_1_1ShepardController.html", null ],
                [ "SpecMeterController", "classSteinberg_1_1Vst_1_1mda_1_1SpecMeterController.html", null ],
                [ "SplitterController", "classSteinberg_1_1Vst_1_1mda_1_1SplitterController.html", null ],
                [ "StereoController", "classSteinberg_1_1Vst_1_1mda_1_1StereoController.html", null ],
                [ "SubSynthController", "classSteinberg_1_1Vst_1_1mda_1_1SubSynthController.html", null ],
                [ "TalkBoxController", "classSteinberg_1_1Vst_1_1mda_1_1TalkBoxController.html", null ],
                [ "TestToneController", "classSteinberg_1_1Vst_1_1mda_1_1TestToneController.html", null ],
                [ "ThruZeroController", "classSteinberg_1_1Vst_1_1mda_1_1ThruZeroController.html", null ],
                [ "TrackerController", "classSteinberg_1_1Vst_1_1mda_1_1TrackerController.html", null ]
              ] ]
            ] ],
            [ "Controller", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1Controller.html", [
              [ "ControllerWithUI", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html", null ]
            ] ],
            [ "SyncDelayController", "classSteinberg_1_1Vst_1_1SyncDelayController.html", null ]
          ] ]
        ] ],
        [ "IComponent", "../vstinterfaces/classSteinberg_1_1Vst_1_1IComponent.html", [
          [ "Component", "../vstsdk/classSteinberg_1_1Vst_1_1Component.html", null ]
        ] ],
        [ "IEditController", "../vstinterfaces/classSteinberg_1_1Vst_1_1IEditController.html", [
          [ "EditController", "../vstsdk/classSteinberg_1_1Vst_1_1EditController.html", null ]
        ] ]
      ] ],
      [ "ITestResult", "../vstinterfaces/classSteinberg_1_1ITestResult.html", [
        [ "Validator", "classSteinberg_1_1Vst_1_1Validator.html", null ]
      ] ],
      [ "ITestSuite", "../vstinterfaces/classSteinberg_1_1ITestSuite.html", [
        [ "TestSuite", "classSteinberg_1_1Vst_1_1TestSuite.html", null ]
      ] ],
      [ "IInfoListener", "../vstinterfaces/classSteinberg_1_1Vst_1_1ChannelContext_1_1IInfoListener.html", [
        [ "HostCheckerController", "classSteinberg_1_1Vst_1_1HostCheckerController.html", null ],
        [ "PlugController", "classSteinberg_1_1Vst_1_1PlugController.html", null ]
      ] ],
      [ "IAudioPresentationLatency", "../vstinterfaces/classSteinberg_1_1Vst_1_1IAudioPresentationLatency.html", [
        [ "HostCheckerProcessor", "classSteinberg_1_1Vst_1_1HostCheckerProcessor.html", null ]
      ] ],
      [ "IAudioProcessor", "../vstinterfaces/classSteinberg_1_1Vst_1_1IAudioProcessor.html", [
        [ "AudioEffect", "../vstsdk/classSteinberg_1_1Vst_1_1AudioEffect.html", null ]
      ] ],
      [ "IAutomationState", "../vstinterfaces/classSteinberg_1_1Vst_1_1IAutomationState.html", [
        [ "HostCheckerController", "classSteinberg_1_1Vst_1_1HostCheckerController.html", null ]
      ] ],
      [ "IConnectionPoint", "../vstinterfaces/classSteinberg_1_1Vst_1_1IConnectionPoint.html", [
        [ "ComponentBase", "../vstsdk/classSteinberg_1_1Vst_1_1ComponentBase.html", null ]
      ] ],
      [ "IDataExchangeReceiver", "../vstinterfaces/classSteinberg_1_1Vst_1_1IDataExchangeReceiver.html", [
        [ "HostCheckerController", "classSteinberg_1_1Vst_1_1HostCheckerController.html", null ]
      ] ],
      [ "IDelayTestController", "classSteinberg_1_1Vst_1_1IDelayTestController.html", [
        [ "ADelayController", "classSteinberg_1_1Vst_1_1ADelayController.html", null ]
      ] ],
      [ "IEditController2", "../vstinterfaces/classSteinberg_1_1Vst_1_1IEditController2.html", [
        [ "EditController", "../vstsdk/classSteinberg_1_1Vst_1_1EditController.html", null ]
      ] ],
      [ "IEditControllerHostEditing", "../vstinterfaces/classSteinberg_1_1Vst_1_1IEditControllerHostEditing.html", [
        [ "HostCheckerController", "classSteinberg_1_1Vst_1_1HostCheckerController.html", null ]
      ] ],
      [ "IHostApplication", "../vstinterfaces/classSteinberg_1_1Vst_1_1IHostApplication.html", [
        [ "Validator", "classSteinberg_1_1Vst_1_1Validator.html", null ]
      ] ],
      [ "IKeyswitchController", "../vstinterfaces/classSteinberg_1_1Vst_1_1IKeyswitchController.html", [
        [ "HostCheckerController", "classSteinberg_1_1Vst_1_1HostCheckerController.html", null ]
      ] ],
      [ "IMidiLearn", "../vstinterfaces/classSteinberg_1_1Vst_1_1IMidiLearn.html", [
        [ "HostCheckerController", "classSteinberg_1_1Vst_1_1HostCheckerController.html", null ],
        [ "ControllerWithUI", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html", null ]
      ] ],
      [ "IMidiLearn2", "../vstinterfaces/classSteinberg_1_1Vst_1_1IMidiLearn2.html", [
        [ "ControllerWithUI", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html", null ]
      ] ],
      [ "IMidiMapping", "../vstinterfaces/classSteinberg_1_1Vst_1_1IMidiMapping.html", [
        [ "AGainController", "classSteinberg_1_1Vst_1_1AGainController.html", null ],
        [ "HostCheckerController", "classSteinberg_1_1Vst_1_1HostCheckerController.html", null ],
        [ "Controller", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1Controller.html", null ],
        [ "BaseController", "classSteinberg_1_1Vst_1_1mda_1_1BaseController.html", null ]
      ] ],
      [ "IMidiMapping2", "../vstinterfaces/classSteinberg_1_1Vst_1_1IMidiMapping2.html", [
        [ "Controller", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1Controller.html", null ]
      ] ],
      [ "INoteExpressionController", "../vstinterfaces/classSteinberg_1_1Vst_1_1INoteExpressionController.html", [
        [ "HostCheckerController", "classSteinberg_1_1Vst_1_1HostCheckerController.html", null ],
        [ "Controller", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1Controller.html", null ],
        [ "PlugController", "classSteinberg_1_1Vst_1_1PlugController.html", null ]
      ] ],
      [ "INoteExpressionPhysicalUIMapping", "../vstinterfaces/classSteinberg_1_1Vst_1_1INoteExpressionPhysicalUIMapping.html", [
        [ "HostCheckerController", "classSteinberg_1_1Vst_1_1HostCheckerController.html", null ],
        [ "Controller", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1Controller.html", null ]
      ] ],
      [ "IParameterFunctionName", "../vstinterfaces/classSteinberg_1_1Vst_1_1IParameterFunctionName.html", [
        [ "HostCheckerController", "classSteinberg_1_1Vst_1_1HostCheckerController.html", null ]
      ] ],
      [ "IPrefetchableSupport", "../vstinterfaces/classSteinberg_1_1Vst_1_1IPrefetchableSupport.html", [
        [ "HostCheckerProcessor", "classSteinberg_1_1Vst_1_1HostCheckerProcessor.html", null ],
        [ "Plug", "classSteinberg_1_1Vst_1_1Plug.html", null ]
      ] ],
      [ "IProcessContextRequirements", "../vstinterfaces/classSteinberg_1_1Vst_1_1IProcessContextRequirements.html", [
        [ "AudioEffect", "../vstsdk/classSteinberg_1_1Vst_1_1AudioEffect.html", null ]
      ] ],
      [ "IRemapParamID", "../vstinterfaces/classSteinberg_1_1Vst_1_1IRemapParamID.html", [
        [ "HostCheckerController", "classSteinberg_1_1Vst_1_1HostCheckerController.html", null ]
      ] ],
      [ "IUnitInfo", "../vstinterfaces/classSteinberg_1_1Vst_1_1IUnitInfo.html", [
        [ "EditControllerEx1", "../vstsdk/classSteinberg_1_1Vst_1_1EditControllerEx1.html", null ]
      ] ],
      [ "IXmlRepresentationController", "../vstinterfaces/classSteinberg_1_1Vst_1_1IXmlRepresentationController.html", [
        [ "HostCheckerController", "classSteinberg_1_1Vst_1_1HostCheckerController.html", null ]
      ] ]
    ] ],
    [ "GlobalParameterState", "structSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1GlobalParameterState.html", null ],
    [ "HostCheck", "classHostCheck.html", null ],
    [ "IApplication", null, [
      [ "App", "classSteinberg_1_1Vst_1_1AudioHost_1_1App.html", null ]
    ] ],
    [ "IApplication", null, [
      [ "App", "classSteinberg_1_1Vst_1_1EditorHost_1_1App.html", null ]
    ] ],
    [ "IController", null, [
      [ "AGainUIMessageController< AGainController >", "classSteinberg_1_1Vst_1_1AGainUIMessageController.html", null ],
      [ "AGainUIMessageController< ControllerType >", "classSteinberg_1_1Vst_1_1AGainUIMessageController.html", null ],
      [ "EditorSizeController", "classSteinberg_1_1Vst_1_1EditorSizeController.html", null ],
      [ "NoteTouchController", "classVSTGUI_1_1NoteTouchController.html", null ]
    ] ],
    [ "KGRP", "structSteinberg_1_1Vst_1_1mda_1_1EPianoProcessor_1_1KGRP.html", null ],
    [ "KGRP", "structSteinberg_1_1Vst_1_1mda_1_1PianoProcessor_1_1KGRP.html", null ],
    [ "LogEvent", "structLogEvent.html", null ],
    [ "LogScale< T >", "classSteinberg_1_1Vst_1_1LogScale.html", null ],
    [ "ModuleTestConfig", "structSteinberg_1_1Vst_1_1Validator_1_1ModuleTestConfig.html", null ],
    [ "Parameter", "../vstsdk/classSteinberg_1_1Vst_1_1Parameter.html", [
      [ "LogScaleParameter< T >", "classSteinberg_1_1Vst_1_1LogScaleParameter.html", null ],
      [ "BaseParameter", "classSteinberg_1_1Vst_1_1mda_1_1BaseParameter.html", [
        [ "IndexedParameter", "classSteinberg_1_1Vst_1_1mda_1_1IndexedParameter.html", null ],
        [ "ScaledParameter", "classSteinberg_1_1Vst_1_1mda_1_1ScaledParameter.html", null ]
      ] ],
      [ "ProxyParameter", "classSteinberg_1_1Vst_1_1mda_1_1ProxyParameter.html", null ]
    ] ],
    [ "ParameterChangesCheck", "classParameterChangesCheck.html", null ],
    [ "ProcessContextCheck", "classProcessContextCheck.html", null ],
    [ "ProcessSetupCheck", "classProcessSetupCheck.html", null ],
    [ "ScoreEntry", "structSteinberg_1_1Vst_1_1HostCheckerController_1_1ScoreEntry.html", null ],
    [ "SyncEntry", "structSteinberg_1_1Vst_1_1SyncEntry.html", null ],
    [ "SynthData< VoiceT, kEventBufferSize, kNumVoices >", "structSteinberg_1_1Vst_1_1mda_1_1SynthData.html", null ],
    [ "UIViewController", null, [
      [ "VSTInterAppAudioHostUIControllerViewController", "interfaceVSTInterAppAudioHostUIControllerViewController.html", null ]
    ] ],
    [ "ViewListenerAdapter", null, [
      [ "AGainUIMessageController< AGainController >", "classSteinberg_1_1Vst_1_1AGainUIMessageController.html", null ],
      [ "AGainUIMessageController< ControllerType >", "classSteinberg_1_1Vst_1_1AGainUIMessageController.html", null ]
    ] ],
    [ "VOICE", "structSteinberg_1_1Vst_1_1mda_1_1DX10Processor_1_1VOICE.html", null ],
    [ "VOICE", "structSteinberg_1_1Vst_1_1mda_1_1EPianoProcessor_1_1VOICE.html", null ],
    [ "VOICE", "structSteinberg_1_1Vst_1_1mda_1_1JX10Processor_1_1VOICE.html", null ],
    [ "VOICE", "structSteinberg_1_1Vst_1_1mda_1_1PianoProcessor_1_1VOICE.html", null ],
    [ "VoiceBase< numValues, SamplePrecision, numChannels, GlobalParameterStorage >", "classSteinberg_1_1Vst_1_1VoiceBase.html", null ],
    [ "VoiceBase< kNumParameters, SamplePrecision, 2, GlobalParameterState >", "classSteinberg_1_1Vst_1_1VoiceBase.html", [
      [ "Voice< SamplePrecision >", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1Voice.html", null ]
    ] ],
    [ "VoiceProcessor", "classSteinberg_1_1Vst_1_1VoiceProcessor.html", [
      [ "VoiceProcessorImplementation< Precision, VoiceClass, numChannels, maxVoices, GlobalParameterStorage >", "classSteinberg_1_1Vst_1_1VoiceProcessorImplementation.html", null ]
    ] ],
    [ "VoiceStatics", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1VoiceStatics.html", null ],
    [ "VST3EditorDelegate", null, [
      [ "AGainController", "classSteinberg_1_1Vst_1_1AGainController.html", null ],
      [ "HostCheckerController", "classSteinberg_1_1Vst_1_1HostCheckerController.html", null ],
      [ "ControllerWithUI", "classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html", null ],
      [ "PitchNamesController", "classSteinberg_1_1Vst_1_1PitchNamesController.html", null ],
      [ "PlugController", "classSteinberg_1_1Vst_1_1PlugController.html", null ]
    ] ],
    [ "VSTInterAppAudioAppDelegateBase", "../vstsdk/interfaceVSTInterAppAudioAppDelegateBase.html", [
      [ "VSTInterAppAudioAppDelegate", "interfaceVSTInterAppAudioAppDelegate.html", null ]
    ] ]
];